@@ -1,7 +1,12 @@
+//
+// Copyright(c) 2015 Gabi Melman.
+// Distributed under the MIT License (http://opensource.org/licenses/MIT)
+//
+
 #include <thread>
 #include <vector>
 #include <atomic>
-
+#include <cstdlib>
 #include "spdlog/spdlog.h"
 
 
@@ -12,7 +17,7 @@ int main(int argc, char* argv[])
 
     int thread_count = 10;
     if(argc > 1)
-        thread_count = atoi(argv[1]);
+        thread_count = std::atoi(argv[1]);
 
     int howmany = 1000000;
 
